@@ -185,7 +185,9 @@ sub cleanup {
         $schema->storage->with_deferred_fk_checks(sub {
             foreach my $source ($schema->sources) {
                 my $table = $schema->source($source)->name;
-                $schema->storage->dbh->do("drop table $table");
+                $schema->storage->dbh->do("drop table $table")
+                    if !($schema->source($source)->can('is_virtual') && 
+                        $schema->source($source)->is_virtual);
             }
         });
     }
